users.User (User) — amici1

# `users.User` (User)

User(id, email, language, modified, created, start_date, end_date, password, last_login, username, user_type, initials, first_name, last_name, remarks, partner, time_zone, date_format, dashboard_layout)

Master tables : users.AllUsers (Users), users.Me (My settings), users.UsersOverview (Users)

Slave tables : cal.SubscriptionsByUser (Subscriptions), cal.TasksByUser (Tasks), dashboard.WidgetsByUser (Dashboard), users.AuthoritiesGiven (Authorities given), users.AuthoritiesTaken (Authorities taken)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- e-mail address (email) : See `<django.db.models.fields.EmailField: email>`.

- Language (language) : See `<lino.utils.mldbc.fields.LanguageField: language>`.

- Modified (modified) : The time when this database object was last modified.

- Created (created) : The time when this object was created.

- Start date (start_date) : If start_date is given, then the user cannot sign in before that date. If end_date is given, then the user cannot sign in after that date.

- End date (end_date) : See `<django.db.models.fields.DateField: end_date>`.

- password (password) : See `<django.db.models.fields.CharField: password>`.

- last login (last_login) : Not used in Lino.

- Username (username) : Must be either unique or empty. Users with an empty username cannot sign in.

- User type (user_type) : The user type assigned to this user. User accounts having this field empty cannot be used to sign in.

- Initials (initials) : The nickname or initials of this user. This does not need to be unique but should be reasonably identifying.

- First name (first_name) : See `<django.db.models.fields.CharField: first_name>`.

- Last name (last_name) : See `<django.db.models.fields.CharField: last_name>`.

- Remarks (remarks) : See `<django.db.models.fields.TextField: remarks>`.

- Partner (partner) : The partner record with additional contact information about this user account.

- Time zone (time_zone) : The time zone Lino should use in time fields or when displaying timestamps to this user.

- Date format (date_format) : The date format to use when parsing or displaying dates.

- dashboard layout (dashboard_layout) : See `<lino.core.choicelists.ChoiceListField: dashboard_layout>`.

- Default access class (access_class) : The default access class for your calendar events and tasks.

- Calendar entry type (event_type) : The default type for your calendar entries.

- Person (person) : A virtual read-only field that returns the Person MTI child of the partner (if it exists) and otherwise None.

- Organization (company) : A virtual read-only field that returns the Company MTI child of the partner (if it exists) and otherwise None.

- Name (name_column) : See `lino.modlib.users.models.User.name_column`.

- (None) (navigation_panel) : See `lino.modlib.users.models.User.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.users.models.User.overview`.

- Created (created_natural) : See `lino.modlib.users.models.User.created_natural`.

Referenced from blogs.Entry.user, cal.Event.assigned_to, cal.Event.user, cal.RecurrentEvent.user, cal.Subscription.user, cal.Task.user, checkdata.Problem.user, comments.Comment.user, comments.Mention.user, comments.Reaction.user, courses.Course.user, courses.Enrolment.user, dashboard.Widget.user, excerpts.Excerpt.user, ledger.LedgerInfo.user, ledger.Voucher.user, uploads.Upload.user, users.Authority.authorized, users.Authority.user

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
email | e-mail address |
language | Language |
modified | Modified | The time when this database object was last modified.
created | Created | The time when this object was created.
start_date | Start date | If start_date is given, then the user cannot sign in before that date. If end_date is given, then the user cannot sign in after that date.
end_date | End date |
password | password |
last_login | last login | Not used in Lino.
username | Username | Must be either unique or empty. Users with an empty username cannot sign in.
user_type | User type | The user type assigned to this user. User accounts having this field empty cannot be used to sign in.
initials | Initials | The nickname or initials of this user. This does not need to be unique but should be reasonably identifying.
first_name | First name |
last_name | Last name |
remarks | Remarks |
partner | Partner | The partner record with additional contact information about this user account.
time_zone | Time zone | The time zone Lino should use in time fields or when displaying timestamps to this user.
date_format | Date format | The date format to use when parsing or displaying dates.
dashboard_layout | dashboard layout |
access_class | Default access class | The default access class for your calendar events and tasks.
event_type | Calendar entry type | The default type for your calendar entries.
person | Person | A virtual read-only field that returns the Person MTI child of the partner (if it exists) and otherwise None.
company | Organization | A virtual read-only field that returns the Company MTI child of the partner (if it exists) and otherwise None.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
created_natural | Created |